### MMGen Version 0.9.9 Release Notes

#### New features:

 - Full Ethereum (`adef0b3`), Ethereum Classic (`d4eb8f6`) and ERC20 token (`881d559`) support

   Testing level for this feature has moved from EXPERIMENTAL to BETA

   For usage details, see https://github.com/mmgen/mmgen/wiki/Altcoin-and-Forkcoin-Support

   NOTE: This release is compatible only with Bitcoin Core v0.16.3 and older. A compatibility patch for v0.17.0 and newer will be included in forthcoming sub-release 0.9.9a

   This is a Linux-only release
